==> eam-wshub-proxyclient-11.4-12-sources.jar: net/datastream/schemas/mp_entities/activity_001/ObjectFactory.java <==

package net.datastream.schemas.mp_entities.activity_001;

import javax.xml.bind.annotation.XmlRegistry;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the net.datastream.schemas.mp_entities.activity_001 package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {


    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: net.datastream.schemas.mp_entities.activity_001
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link Activity }
     * 
     */
    public Activity createActivity() {
        return new Activity();
    }

    /**
     * Create an instance of {@link WorkOrderEquipments }
     * 
     */
    public WorkOrderEquipments createWorkOrderEquipments() {
        return new WorkOrderEquipments();
    }

    /**
     * Create an instance of {@link WorkOrderEquipment }
     * 
     */
    public WorkOrderEquipment createWorkOrderEquipment() {
        return new WorkOrderEquipment();
    }

    /**
     * Create an instance of {@link UserDefinedFields }
     * 
     */
    public UserDefinedFields createUserDefinedFields() {
        return new UserDefinedFields();
    }

}

==> eam-wshub-proxyclient-12.1-1-sources.jar: net/datastream/schemas/mp_entities/activity_001/ObjectFactory.java <==

package net.datastream.schemas.mp_entities.activity_001;

import jakarta.xml.bind.annotation.XmlRegistry;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the net.datastream.schemas.mp_entities.activity_001 package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {


    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: net.datastream.schemas.mp_entities.activity_001
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link Activity }
     * 
     * @return
     *     the new instance of {@link Activity }
     */
    public Activity createActivity() {
        return new Activity();
    }

    /**
     * Create an instance of {@link WorkOrderEquipments }
     * 
     * @return
     *     the new instance of {@link WorkOrderEquipments }
     */
    public WorkOrderEquipments createWorkOrderEquipments() {
        return new WorkOrderEquipments();
    }

    /**
     * Create an instance of {@link WorkOrderEquipment }
     * 
     * @return
     *     the new instance of {@link WorkOrderEquipment }
     */
    public WorkOrderEquipment createWorkOrderEquipment() {
        return new WorkOrderEquipment();
    }

    /**
     * Create an instance of {@link UserDefinedFields }
     * 
     * @return
     *     the new instance of {@link UserDefinedFields }
     */
    public UserDefinedFields createUserDefinedFields() {
        return new UserDefinedFields();
    }

}
